@@ -1,9 +1,7 @@
 # -*- coding: utf-8 -*-
 """
-VK.com (former Vkontakte) OpenAPI and OAuth 2.0 support.
-
-This backend adds support for VK.com OpenAPI, OAuth2 and OAuth2 for IFrame
-applications.
+VK.com OpenAPI, OAuth2 and Iframe application OAuth2 backends, docs at:
+    http://psa.matiasaguirre.net/docs/backends/vk.html
 """
 from time import time
 from hashlib import md5
@@ -82,7 +80,7 @@ class VKOAuth2(BaseOAuth2):
     ACCESS_TOKEN_METHOD = 'POST'
     EXTRA_DATA = [
         ('id', 'id'),
-        ('expires', 'expires')
+        ('expires_in', 'expires')
     ]
 
     def get_user_details(self, response):
@@ -123,7 +121,10 @@ class VKAppOAuth2(VKOAuth2):
     name = 'vk-app'
 
     def user_profile(self, user_id, access_token=None):
-        data = {'uids': user_id, 'fields': 'photo'}
+        request_data = ['first_name', 'last_name', 'screen_name', 'nickname',
+                        'photo'] + self.setting('EXTRA_DATA', [])
+        fields = ','.join(set(request_data))
+        data = {'uids': user_id, 'fields': fields}
         if access_token:
             data['access_token'] = access_token
         profiles = vk_api(self, 'getProfiles', data).get('response')
