@@ -1,16 +1,8 @@
 #coding:utf8
-#author:hepochen@gmail.com  https://github.com/hepochen
+# author:hepochen@gmail.com  https://github.com/hepochen
 """
-Weibo OAuth2 support.
-
-This script adds support for Weibo OAuth service. An application must
-be registered first on http://open.weibo.com.
-
-WEIBO_CLIENT_KEY and WEIBO_CLIENT_SECRET must be defined in the settings.py
-correctly.
-
-By default account id,profile_image_url,gender are stored in extra_data field,
-check OAuthBackend class for details on how to extend it.
+Weibo OAuth2 backend, docs at:
+    http://psa.matiasaguirre.net/docs/backends/weibo.html
 """
 from social.backends.oauth import BaseOAuth2
 
@@ -22,6 +14,7 @@ class WeiboOAuth2(BaseOAuth2):
     AUTHORIZATION_URL = 'https://api.weibo.com/oauth2/authorize'
     REQUEST_TOKEN_URL = 'https://api.weibo.com/oauth2/request_token'
     ACCESS_TOKEN_URL = 'https://api.weibo.com/oauth2/access_token'
+    ACCESS_TOKEN_METHOD = 'POST'
     REDIRECT_STATE = False
     EXTRA_DATA = [
         ('id', 'id'),
@@ -40,4 +33,4 @@ class WeiboOAuth2(BaseOAuth2):
     def user_data(self, access_token, *args, **kwargs):
         return self.get_json('https://api.weibo.com/2/users/show.json',
                              params={'access_token': access_token,
-                                     'uid': args[0]['uid']})
+                                     'uid': kwargs['response']['uid']})
